==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/skoleni/skoleniakurzybrowser.php <==
<?php
/**
 * Lektorem spravovane kurzy
 * Roman.Szablatura RON Software 30.8.2017
 */

namespace RonPortal\Skoleni;

use Ron\Controls\BrowserField;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\Controls\ComboBox;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;


/**
 * Class SkoleniKurzyFilterForm
 * @package Ron\RonPortal
 */
class SkoleniKurzyFilterForm extends SkoleniFilterForm
{
    /** @var PravaNaOsoby $prava*/
    var $prava;

    public $stavSkoleni = null;

    public $jenDlouhodobeKurzy = false;

    /**
     * SkoleniKurzyFilterForm constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        parent::__construct($database, ['menuid' => 'skoleni', 'action' => 'skolenikurzy'], true);

        $this->prava = Prava::vratPrava('skoleni_lektor');
        Prava::nastavObdobiProPrava(time(),time());

        //Zobrazeni FilterFormu pro nastaveni data od - do
        $this->nastavDatumOdDo(true, false, TextManager::_('skoleni_v_obdobi') . ' ' . TextManager::_('Od'));
    }


//    /**
//     * Volba druhu skoleni
//     * @throws DBException
//     */
//    function renderTypSkoleni()
//    {
//        echo '<div class="filterrow">';
//        echo '<span class="filtercaption">';
//        GuiUtils::renderCheckbox('jenTypSkoleniAKurzu', ronText('typ_skoleni'). '&nbsp;&nbsp;', $_SESSION['jenTypSkoleniAKurzu'],
//            'onClick="submit()"');
//        echo '</span>';
//
//        $sql =
//            "SELECT Distinct DruhSkoleni.Kod, DruhSkoleni.Popis
//             FROM DruhSkoleni LEFT JOIN Skoleni ON (DruhSkoleni.Kod = Skoleni.DruhSkoleni)
//             WHERE (Skoleni.StavSkoleni < 2)
//             ORDER BY DruhSkoleni.Popis";
//
//        $combo = new ComboBox('typSkoleniAKurzu');
//        $combo->className = 'app_combo adsfilterforminput_full';
//        $combo->htmlParams = 'onChange="if (jenTypSkoleniAKurzu.checked) submit();"';
//        $combo->showCode = 1;
//        $combo->loadData($this->database, $sql, $_SESSION['typSkoleniAKurzu']);
//        $combo->render();
//        echo '</div>';
//    }


//    /**
//     * Filtr pro aktualni obdobi nabidne aktualni mesic, aktualni ctvrtleti, aktualni pololeti
//     */
//    function renderAktualniObdobi()
//    {
//        $aktualniMesic = $this->vratAktualniMesic();
//        $aktualniCtvrtleti = $this->vratAktualniCtvrtleti();
//        $aktualniPololeti = $this->vratAktualniPololeti();
//
//
//        //Hodnoty obdobi[0] 1-mesic, 3-ctvrtleti, 6-pololeti
//        $obdobi = explode('_', $_SESSION['aktualniObdobi']);
//
//        $mesic = "1_$aktualniMesic[0]_$aktualniMesic[1]";
//        $ctvrtleti = "3_$aktualniCtvrtleti[0]_$aktualniCtvrtleti[1]";
//        $pololeti = "6_$aktualniPololeti[0]_$aktualniPololeti[1]";
//
//        $mesicText =  date('j.n.Y G:i:s', $aktualniMesic[0]) . "&nbsp;&nbsp;-&nbsp;&nbsp;" . date('j.n.Y G:i:s', $aktualniMesic[1]);
//        $ctvrtletiText =  date('j.n.Y G:i:s', $aktualniCtvrtleti[0]) . "&nbsp;&nbsp;-&nbsp;&nbsp;" . date('j.n.Y G:i:s', $aktualniCtvrtleti[1]);
//        $pololetiText =  date('j.n.Y G:i:s', $aktualniPololeti[0]) . "&nbsp;&nbsp;-&nbsp;&nbsp;" . date('j.n.Y G:i:s', $aktualniPololeti[1]);
//        $titulekCombaZvolenehoObdobi = "";
//
//        if ($obdobi[0] == 1){
//            $titulekCombaZvolenehoObdobi = $mesicText;
//        }
//
//        if ($obdobi[0] == 3){
//            $titulekCombaZvolenehoObdobi = $ctvrtletiText;
//        }
//
//        if ($obdobi[0] == 6){
//            $titulekCombaZvolenehoObdobi = $pololetiText;
//        }
//
//        echo "<div class='filterrow'>";
//        echo "<span title='" . ronText('filtr_pouze_v_obdobi') . "' class='filtercaption'>";
//        GuiUtils::renderCheckbox('jenAktualniObdobi', ronText('skoleni_v_obdobi'). '&nbsp;&nbsp;', $_SESSION['jenAktualniObdobi'],
//            'onClick="submit()"');
//        echo '</span>';
//
//
//        $combo = "";
//        $combo .= '<div class="tooltipek">';
//        $combo .=
//            "<select class='app_combo adsfilterforminput_full' name='aktualniObdobi' id='aktualniObdobi' onchange='this.form.submit()'>" .
//                    "<option value='$mesic' " . ($obdobi[0] == 1 ? 'selected':'') . ">" . ronText('aktualni_mesic') . '</option>' .
//                "</optgroup>" .
//
//                    "<option value='$ctvrtleti' " . ($obdobi[0] == 3 ? 'selected':'') . ">" . ronText('aktualni_ctvrtleti') . '</option>' .
//                "</optgroup>" .
//
//                    "<option value='$pololeti' " . ($obdobi[0] == 6 ? 'selected':'') . ">" . ronText('aktualni_pololeti') . '</option>' .
//                "</optgroup>" .
//            '</select>';
//
//        $combo .= '<span>' . ronText('skoleni_v_obdobi') . ':&nbsp;&nbsp;' .  $titulekCombaZvolenehoObdobi . '</span></div>';
//
//        echo $combo;
//        echo "<br>";
//        echo '</div>';
//    }


//    /**
//     * Z aktualniho data zjisti mesic
//     * @return array
//     */
//    private function vratAktualniMesic()
//    {
//        $zacatekMesice = (DateUtils::firstDayOfMonth(time()));
//        $konecMesice = (DateUtils::incMonth(DateUtils::firstDayOfMonth( time()), 1)-1);
//
//        //Vraci pole s timestamp
//        return [$zacatekMesice, $konecMesice];
//    }


//    /**
//     * Z aktualniho data zjisti rozsah ctvrtleti
//     * @return array
//     */
//    private function vratAktualniCtvrtleti()
//    {
//        $aktualniMesic = date('n', time());
//        $aktualniCtvrtleti = [];
//
//        if ($aktualniMesic >= 1 && $aktualniMesic <= 3){
//            // 1 ctvrtleti;
//
//            $zacatek = mktime(0, 0, 0, 1, 1, date('Y', time()));
//            $konec = DateUtils::incMonth($zacatek, 3) - 1;
//
//            $aktualniCtvrtleti[0] = ($zacatek);
//            $aktualniCtvrtleti[1] = ($konec);
//        } elseif ($aktualniMesic >= 4 && $aktualniMesic <= 6){
//            // 2 ctvrtleti;
//
//            $zacatek = mktime(0, 0, 0, 4, 1, date('Y', time()));
//            $konec = DateUtils::incMonth($zacatek, 3) - 1;
//
//            $aktualniCtvrtleti[0] = ($zacatek);
//            $aktualniCtvrtleti[1] = ($konec);
//        } elseif ($aktualniMesic >= 7 && $aktualniMesic <= 9) {
//            // 3 ctvrtleti;
//            $zacatek = mktime(0, 0, 0, 7, 1, date('Y', time()));
//            $konec = DateUtils::incMonth($zacatek, 3) - 1;
//
//            $aktualniCtvrtleti[0] = ($zacatek);
//            $aktualniCtvrtleti[1] = ($konec);
//
//
//        } elseif($aktualniMesic >= 10 && $aktualniMesic <= 12) {
//            // 4 ctvrtleti;
//
//            $zacatek = mktime(0, 0, 0, 10, 1, date('Y', time()));
//            $konec = DateUtils::incMonth($zacatek, 3) - 1;
//
//            $aktualniCtvrtleti[0] = ($zacatek);
//            $aktualniCtvrtleti[1] = ($konec);
//
//        }
//
//        //Vraci pole s timestamp
//        return $aktualniCtvrtleti;
//    }


//    /**
//     * Z aktualniho data zjisti rozsah pololeti
//     * @return array
//     */
//    private function vratAktualniPololeti()
//    {
//        $aktualniMesic = date('n', time());
//        $aktualniPololeti = [];
//
//        if ($aktualniMesic >= 1 && $aktualniMesic <= 6){
//            // 1 ctvrtleti;
//
//            $zacatek = mktime(0, 0, 0, 1, 1, date('Y', time()));
//            $konec = DateUtils::incMonth($zacatek, 6) - 1;
//
//            $aktualniPololeti[0] = ($zacatek);
//            $aktualniPololeti[1] = ($konec);
//        } elseif ($aktualniMesic >= 7 && $aktualniMesic <= 12) {
//            // 2 ctvrtleti;
//
//            $zacatek = mktime(0, 0, 0, 7, 1, date('Y', time()));
//            $konec = DateUtils::incMonth($zacatek, 6) - 1;
//
//            $aktualniPololeti[0] = ($zacatek);
//            $aktualniPololeti[1] = ($konec);
//        }
//
//        //Vraci pole s timestamp
//        return $aktualniPololeti;
//    }


    /**
     * Stav skoleni
     * @throws DBException
     */
     function renderStavSkoleni()
    {
        echo
            '<div class="filterrow">';
//        echo '<span class="filtercaption">';
//        GuiUtils::renderCheckbox('jenStavSkoleniAKurzu', ronText('Stav_skoleni'). '&nbsp;&nbsp;', $_SESSION['jenStavSkoleniAKurzu'],
//            'onClick="submit()"');
//        echo '</span>';
        echo
            '<span class="filtercaption">' .
            TextManager::_('Stav_skoleni') .
            '</span>';

        $combo = new ComboBox('stav');
        $combo->emptyRow = TextManager::_('_vse_');

        $combo->className = 'form-input adsfilterforminput_full';
        $combo->htmlParams = [
            'data-ron-autosubmit' => '1',
        ];
         $combo ->dataTypeComparison = false;
        $combo->loadData($this ->database,
            'SELECT DISTINCT Kod, Popis FROM S_StavSkoleni WHERE S_StavSkoleni.Kod < 2 ORDER BY Popis',
            $this ->stavSkoleni);
        $combo->render();

        echo '</div>';
    }

    /**
     * Check pro pouze dlouhodoby kurz
     */
    function renderDlouhodobyKurz()
    {
        //Dlouhodoby kurz
        echo
            '<div class="filterrow">';
        echo
            '<span class="filtercaption">' .
            '</span>';

        echo '<span>';
        GuiUtils::renderCheckbox('dlouhodobe', TextManager::_('jen_dlouhodoby') . ' ',
            $this ->jenDlouhodobeKurzy,
            '', 'clickAutoSubmit');
        echo '</span>';

        echo '</div>';
    }

//    function loadTypSkoleni()
//    {
//        if (isset($_POST['adsfilterform'])) {
//            $_SESSION['jenTypSkoleniAKurzu'] = isset($_POST['jenTypSkoleniAKurzu']);
//            $_SESSION['typSkoleniAKurzu'] = $_POST['typSkoleniAKurzu'];
//        }
//    }

//    function loadAktualniObdobi()
//    {
//        if (isset($_POST['adsfilterform'])) {
//
//            $_SESSION['jenAktualniObdobi'] = isset($_POST['jenAktualniObdobi']);
//            $_SESSION['aktualniObdobi'] = $_POST['aktualniObdobi'];
//
//        }
//    }

    function loadStavSkoleni()
    {
        if (isset($_GET['stav'])) {
            $this ->stavSkoleni = $_GET['stav'];
            if (trim($this ->stavSkoleni === '')) {
                $this ->stavSkoleni = null;
            } else {
                $this ->stavSkoleni = (int)$this ->stavSkoleni;
            }
            $_SESSION['stavSkoleniCB'] = $this ->stavSkoleni;
        } else {
            $this ->stavSkoleni = $_SESSION['stavSkoleniCB'] ?? null;
        }

//        if (isset($_POST['adsfilterform'])) {
//            $_SESSION['jenStavSkoleniAKurzu'] = isset($_POST['jenStavSkoleniAKurzu']);
//            $_SESSION['stavSkoleniAKurzu'] = $_POST['stavSkoleniAKurzu'];
//        }
    }

    private function loadDlouhodobyKurz()
    {
//        if (isset($_POST['adsfilterform'])) {
//            $_SESSION['dlouhodobyKurz'] = isset($_POST['dlouhodobyKurz']);
//        }
        if (isset($_GET['stav'])) {
            $this ->jenDlouhodobeKurzy = isset($_GET['dlouhodobe'])
                ? (int)$_GET['dlouhodobe']
                : 0;
            $_SESSION['jenDlouhodobeSkoleni'] = $this ->jenDlouhodobeKurzy;
        } else {
            $this ->jenDlouhodobeKurzy = $_SESSION['jenDlouhodobeSkoleni'] ?? false;
        }
    }

    function loadData()
    {
//        $this->loadAktualniObdobi();
        $this->loadDruhSkoleni();
        $this->loadStavSkoleni();
        $this->loadDlouhodobyKurz();
        parent::loadData();
    }

    /**
     * @throws DBException
     */
    function renderFilters()
    {
        parent::renderFilters();
//        $this->renderAktualniObdobi();
//        $this->renderTypSkoleni();
        $this->renderDruhSkoleni();
        $this->renderStavSkoleni();
        $this->renderDlouhodobyKurz();
    }
}


/**
 * Class ZaznamenatUcastSkoleniAKurzu
 */
class ZaznamenatUcastSkoleniAKurzu extends BrowserField
{
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        // zobrazuje se jen u dlouhodobych kurzu
        if (!$rowData['col-dlouhodobykurz']) {
            return '';
        }

        return parent::getViewText($value, $rowNumber, $recordId, $rowData);
    }
}


/**
 * Class ZaznamenatHodnoceniSkoleniAKurzu
 */
class ZaznamenatHodnoceniSkoleniAKurzu extends BrowserField
{
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        // u dlouhodobych kurzu se nezobrazuje
        if ($rowData['col-dlouhodobykurz']) {
            return '';
        }

        return parent::getViewText($value, $rowNumber, $recordId, $rowData);
    }
}



/**
 * Class SkoleniAKurzyBrowser
 * Seznam lektorem spravovanych kurzu
 */
class SkoleniAKurzyBrowser extends RonPortalBrowser
{
    /** @var  PravaNaOsoby $pravaLektora */
    private $pravaLektora;

    /**
     * VsechnaSkoleniAKurzy constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct($database)
    {
        parent::__construct($database, 'skoleni');

        $this->pravaLektora = Prava::vratPrava('skoleni_lektor');
        Prava::nastavObdobiProPrava(time(),time());

        $this->code = 'browserskolenikurzy';
        $this->tableId = 'browserskolenikurzy';
        $this->browserUrl = "?menuid=skoleni&action=skolenikurzy";

        $this->sqlSelectPart =
            "CisloSkoleni"; //0

        $this ->primaryField = 0;

        $this->sqlFromPart = "Skoleni " .
            "LEFT JOIN S_StavSkoleni ON (Skoleni.StavSkoleni = S_StavSkoleni.Kod)";

//        $this->filtrForm = new SkoleniKurzyFilterForm($database);
//        $this->filtrForm->loadData();

        $this->addField()
            ->setSqlFieldName('CisloSkoleni', 0) ->setHeaderText("Skoleni_CisloSkoleni")
            ->setCode('col-cisloskoleni')
            ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('DruhSkoleni') ->setHeaderText('typ_skoleni')
            ->setCode('col-druhskoleni') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('Skoleni.Popis') ->setHeaderText('Skoleni_Popis')
            ->setCode('col-popis')
            ->setOrdering(true) ->setClassName('popisSkoleniKurzy');

        $this->addField()
            ->setSqlFieldName('S_StavSkoleni.Popis') // puvodne AS S_SP
            ->setHeaderText('Stav_skoleni')
            ->setCode('col-stavskoleni') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('DatumPocatkuSkoleni') ->setHeaderText('Skoleni_DatumZacatku')
            ->setCode('col-datumpocatkuskoleni')
            ->setFormat('finedate') ->setOrdering(true) ->setAlign('center');

        $this->defaultSort = 'col-datumpocatkuskoleni';

        $this->addField()
            ->setSqlFieldName('DatumUkonceniSkoleni') ->setHeaderText('Skoleni_DatumUkonceni')
            ->setCode('col-datumukonceniskoleni')
            ->setFormat('finedate') ->setOrdering(true) ->setAlign('center');

        $this->addField(new ZaznamenatUcastSkoleniAKurzu())
            ->setType(BrowserField::FIELD_TYPE_TEXT)
            ->setCode('col-zaznamenat-ucast')
            ->setAlign('center') ->setHeaderText('ucast_na_skoleni')
            ->setLink('?menuid=skoleni&action=skoleniucast&cisloskoleni=')
            ->setText(TextManager::_('ucast_na_skoleni'));


        $this->addField(new ZaznamenatHodnoceniSkoleniAKurzu())
            ->setType(BrowserField::FIELD_TYPE_TEXT)
            ->setCode('col-zaznamenat-ucast')
            ->setAlign('center') ->setHeaderText('hodnoceni_skoleni')
            ->setLink('?menuid=skoleni&action=skolenihodnoceni&record=')
            ->setText(TextManager::_('hodnoceni_skoleni'));

        //$this->header = TextManager::_('hodnoceni_skoleni');

        $this->addField(BrowserField::FIELD_TYPE_SELECT)
            ->setSqlFieldName('Skoleni.DlouhodobyKurz') ->setHeaderText('Skoleni_DlouhodobyKurz')
            ->setCode('col-dlouhodobykurz')
            ->setOrdering(true) ->setAlign('center')
            ->setOptions([0 => TextManager::_('Str_No'), 1 => TextManager::_('Str_Yes')]);
//        $this->addField([BROWSER_FIELD_SQL_INDEX => 21, BROWSER_FIELD_SQL_NAME => 'S_AP', BROWSER_FIELD_HEADER_TEXT => ronText('Skoleni_DlouhodobyKurz'),
//            BROWSER_FIELD_ORDERING => 1, BROWSER_FIELD_ALIGN => 'center' ]);

        $this->addField()
            ->setSqlFieldName('Kapacita') ->setHeaderText('Skoleni_Kapacita')
            ->setCode('col-kapacita')
            ->setFormat('number0') ->setOrdering(true) ->setAlign('center');

    }



    function setFilterForm()
    {
        $this->filterForm = new SkoleniKurzyFilterForm($this ->database);
        $this->filterForm->loadData();
    }


    public function enableLine($values)
    {
        if ($this->pravaLektora->prava == 3 ) {
            return true;
        }

        //Dle priznaku 3 zobrazovat kurzy
        if (trim($this->pravaLektora->priznak3) != '') {
            $povoleneTypyKurzu = explode(';', $this->pravaLektora->priznak3);
            return in_array($values[0], $povoleneTypyKurzu);    // konkretni cislo skoleni
        }

        return false;
    }


    /**
     * @return SqlStatement|string
     */
    function getSQLFilter()
    {
        $params = $this->database->createParameters();

        $result = 'Skoleni.StavSkoleni < 2';

        //$obdobi = explode('_', $_SESSION['aktualniObdobi']);

        if ($this ->filterForm instanceof SkoleniKurzyFilterForm) {
            if ($this->filterForm->druhSkoleni) {
                $result .=
                    ($result ? ' AND ' : '') .
                    'Skoleni.DruhSkoleni = ' . $params->addParameter($this->filterForm->druhSkoleni);
            }

            if (isset($this ->filterForm ->stavSkoleni)) {
                $result .=
                    ($result ? ' AND ' : '') .
                    'Skoleni.StavSkoleni = ' . $params->addParameter($this ->filterForm ->stavSkoleni);
            }

            if ($this ->filterForm ->jenDlouhodobeKurzy) {
                $result .=
                    ($result ? ' AND ' : '') .
                    'Skoleni.DlouhodobyKurz = 1';
            }

            if ($this ->filterForm ->filtrovatDatum) {
                $result .=
                    ($result ? ' AND ' : '') .
                    ' Skoleni.DatumPocatkuSkoleni <= ' . $params->addDateParameter($this ->filterForm ->datumDo) .
                    ' AND (Skoleni.DatumUkonceniSkoleni IS NULL OR Skoleni.DatumUkonceniSkoleni >= ' . $params->addDateParameter($this ->filterForm ->datumOd) . ')';
            }

//            if ($_SESSION['jenAktualniObdobi']) {
//                if ($result) {
//                    $result .= ' AND ';
//                }
//                $result .= ' Skoleni.DatumPocatkuSkoleni >= ' . $params->addParameter($this->database->timestampToParam($obdobi[1])) .
//                    ' AND Skoleni.DatumUkonceniSkoleni <= ' . $params->addParameter($this->database->timestampToParam($obdobi[2]));
//            }
        }

        return new SqlStatement($result, $params);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/skoleni/skoleniakurzybrowser.php <==
<?php
/**
 * Lektorem spravovane kurzy
 * Roman.Szablatura RON Software 30.8.2017
 */

namespace RonPortal\Skoleni;

use Ron\Controls\BrowserField;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\FilterFormFilter;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;


/**
 * Class ZaznamenatUcastSkoleniAKurzu
 */
class ZaznamenatUcastSkoleniAKurzu extends BrowserField
{
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        // zobrazuje se jen u dlouhodobych kurzu
        if (!$rowData['col-dlouhodobykurz']) {
            return '';
        }

        return parent::getViewText($value, $rowNumber, $recordId, $rowData);
    }
}


/**
 * Class ZaznamenatHodnoceniSkoleniAKurzu
 */
class ZaznamenatHodnoceniSkoleniAKurzu extends BrowserField
{
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        // u dlouhodobych kurzu se nezobrazuje
        if ($rowData['col-dlouhodobykurz']) {
            return '';
        }

        return parent::getViewText($value, $rowNumber, $recordId, $rowData);
    }
}



/**
 * Class SkoleniAKurzyBrowser
 * Seznam lektorem spravovanych kurzu
 */
class SkoleniAKurzyBrowser extends RonPortalBrowser
{
    /** @var  PravaNaOsoby $pravaLektora */
    private $pravaLektora;

    /**
     * VsechnaSkoleniAKurzy constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct($database)
    {
        parent::__construct($database, 'skoleni');

        $this->pravaLektora = Prava::vratPrava('skoleni_lektor');
        Prava::nastavObdobiProPrava(time(),time());

        $this->code = 'browserskolenikurzy';
        $this->tableId = 'browserskolenikurzy';
        $this->browserUrl = "?menuid=skoleni&action=skolenikurzy";

        $this->sqlSelectPart =
            "CisloSkoleni"; //0

        $this ->primaryField = 0;

        $this->sqlFromPart = "Skoleni " .
            "LEFT JOIN S_StavSkoleni ON (Skoleni.StavSkoleni = S_StavSkoleni.Kod)";

        $this->addField()
            ->setSqlFieldName('CisloSkoleni', 0) ->setHeaderText("Skoleni_CisloSkoleni")
            ->setCode('col-cisloskoleni')
            ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('DruhSkoleni') ->setHeaderText('typ_skoleni')
            ->setCode('col-druhskoleni') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('Skoleni.Popis') ->setHeaderText('Skoleni_Popis')
            ->setCode('col-popis')
            ->setOrdering(true) ->setClassName('popisSkoleniKurzy');

        $this->addField()
            ->setSqlFieldName('S_StavSkoleni.Popis') // puvodne AS S_SP
            ->setHeaderText('Stav_skoleni')
            ->setCode('col-stavskoleni') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('DatumPocatkuSkoleni') ->setHeaderText('Skoleni_DatumZacatku')
            ->setCode('col-datumpocatkuskoleni')
            ->setFormat('finedate') ->setOrdering(true) ->setAlign('center');

        $this->defaultSort = 'col-datumpocatkuskoleni';

        $this->addField()
            ->setSqlFieldName('DatumUkonceniSkoleni') ->setHeaderText('Skoleni_DatumUkonceni')
            ->setCode('col-datumukonceniskoleni')
            ->setFormat('finedate') ->setOrdering(true) ->setAlign('center');

        $this->addField(new ZaznamenatUcastSkoleniAKurzu())
            ->setType(BrowserField::FIELD_TYPE_TEXT)
            ->setCode('col-zaznamenat-ucast')
            ->setAlign('center') ->setHeaderText('ucast_na_skoleni')
            ->setLink('?menuid=skoleni&action=skoleniucast&cisloskoleni=')
            ->setText(TextManager::_('ucast_na_skoleni'));


        $this->addField(new ZaznamenatHodnoceniSkoleniAKurzu())
            ->setType(BrowserField::FIELD_TYPE_TEXT)
            ->setCode('col-zaznamenat-ucast')
            ->setAlign('center') ->setHeaderText('hodnoceni_skoleni')
            ->setLink('?menuid=skoleni&action=skolenihodnoceni&record=')
            ->setText(TextManager::_('hodnoceni_skoleni'));

        $this->addField(BrowserField::FIELD_TYPE_SELECT)
            ->setSqlFieldName('Skoleni.DlouhodobyKurz') ->setHeaderText('Skoleni_DlouhodobyKurz')
            ->setCode('col-dlouhodobykurz')
            ->setOrdering(true) ->setAlign('center')
            ->setOptions([0 => TextManager::_('Str_No'), 1 => TextManager::_('Str_Yes')]);

        $this->addField()
            ->setSqlFieldName('Kapacita') ->setHeaderText('Skoleni_Kapacita')
            ->setCode('col-kapacita')
            ->setFormat('number0') ->setOrdering(true) ->setAlign('center');

    }



    function setFilterForm()
    {
        Prava::nastavObdobiProPrava(time(),time());

        $this->filterForm = new SkoleniFilterForm($this ->database, ['menuid' => 'skoleni', 'action' => 'skolenikurzy'], true);

        //Zobrazeni FilterFormu pro nastaveni data od - do
        $this->filterForm ->nastavDatumOdDo(true, false, TextManager::_('skoleni_v_obdobi') . ' ' . TextManager::_('Od'));

        $this ->filterForm ->addDruhSkoleniFilter();

        $this ->filterForm ->addFilter((new FilterFormFilter('stav'))
            ->setSessionName('stavSkoleniCB')
            ->setCaption(TextManager::_('Stav_skoleni'))
            ->addItem('', TextManager::_('Vse'))
            ->setOptionsSql(
                'SELECT DISTINCT Kod, Popis FROM S_StavSkoleni WHERE %FILTER% ORDER BY %ORDER%',
                'S_StavSkoleni.Kod < 2',
                'Popis')
        );

        $this ->filterForm ->addFilter((new FilterFormFilter('dlouhodobe', FilterFormFilter::TYPE_CHECKBOX))
            ->setSessionName('filtrJenDlouhodobeSkoleni')
            ->setCaption2(TextManager::_('jen_dlouhodoby'))
        );
    }


    public function enableLine($values)
    {
        if ($this->pravaLektora->prava == 3 ) {
            return true;
        }

        //Dle priznaku 3 zobrazovat kurzy
        if (trim($this->pravaLektora->priznak3) != '') {
            $povoleneTypyKurzu = explode(';', $this->pravaLektora->priznak3);
            return in_array($values[0], $povoleneTypyKurzu);    // konkretni cislo skoleni
        }

        return false;
    }


    /**
     * @return SqlStatement|string
     */
    function getSQLFilter()
    {
        $params = $this->database->createParameters();
        $result = $this ->filterForm ->buildSqlFilter($params);

        $result =
            ($result ? ' AND ' : '') .
            'Skoleni.StavSkoleni < 2';

        //$obdobi = explode('_', $_SESSION['aktualniObdobi']);

        if ($this->filterForm->getFilterValue('druhskoleni')) {
            $result .=
                ($result ? ' AND ' : '') .
                'Skoleni.DruhSkoleni = ' . $params->addParameter($this->filterForm->getFilterValue('druhskoleni'));
        }

        if ($this ->filterForm ->getFilterValue('stav') !== null) {
            $result .=
                ($result ? ' AND ' : '') .
                'Skoleni.StavSkoleni = ' . $params->addParameter($this ->filterForm ->getFilterValue('stav'));
        }


        if ($this ->filterForm ->getFilterValue('dlouhodobe')) {
            $result .=
                ($result ? ' AND ' : '') .
                'Skoleni.DlouhodobyKurz = 1';
        }

        if ($this ->filterForm ->filtrovatDatum) {
            $result .=
                ($result ? ' AND ' : '') .
                ' Skoleni.DatumPocatkuSkoleni <= ' . $params->addDateParameter($this ->filterForm ->datumDo) .
                ' AND (Skoleni.DatumUkonceniSkoleni IS NULL OR Skoleni.DatumUkonceniSkoleni >= ' . $params->addDateParameter($this ->filterForm ->datumOd) . ')';
        }

        return new SqlStatement($result, $params);
    }
}
